ExpectedCharRangeError class final
E0004 — a character in a specific range was expected.
- Inheritance
-
- Object
- FluentParseError
- ExpectedCharRangeError
Constructors
- ExpectedCharRangeError(String range, int offset)
-
Creates the error for the expected
rangeatoffset.const
Properties
- code → String
-
Stable identifier (e.g.
E0003).final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of what went wrong.
no setteroverride
- offset → int
-
Byte offset within the source where parsing failed.
final
- range → String
-
Human-readable description of the accepted range.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited