Identifier class final
An identifier — used for message names, term names (without leading dash), attribute names, variant keys, function names, and variable names.
Spec: [a-zA-Z][a-zA-Z0-9_-]*
- Inheritance
-
- Object
- FluentNode
- SyntaxNode
- Identifier
Constructors
- Identifier(String name, {Span? span})
-
Wraps the identifier
name.const
Properties
Methods
-
clone(
) → Identifier -
Deep clone of this node.
override
-
equals(
FluentNode other, {bool ignoreSpans = true}) → bool -
Structural equality.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited