MessageReference class final

A reference to another message: name or name.attr.

Inheritance

Constructors

MessageReference(Identifier id, {Identifier? attribute, Span? span})
References the message id (+ optional attribute).
const

Properties

attribute Identifier?
The referenced attribute, for { msg.attr } forms.
final
hashCode int
The hash code for this object.
no setterinherited
id Identifier
The referenced message's id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span Span?
Source range this node covers; null when spans were off.
final

Methods

clone() MessageReference
Deep clone of this node.
override
equals(FluentNode other, {bool ignoreSpans = true}) bool
Structural equality.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited