NumberLiteralExpression class final

A numeric literal used as a placeable expression.

Inheritance

Constructors

NumberLiteralExpression(NumberLiteral literal, {Span? span})
Wraps the literal.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
literal → NumberLiteral
The wrapped number literal.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → Span?
Source range this node covers; null when spans were off.
final

Methods

clone() → NumberLiteralExpression
Deep clone of this node.
override
equals(FluentNode other, {bool ignoreSpans = true}) → bool
Structural equality.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited