Span class final

A position in the source text. Inclusive start, exclusive end.

Only present on a node when the parser was constructed with span tracking enabled.

Annotations
  • @immutable

Constructors

Span(int start, int end)
Creates the half-open range start..end.
const

Properties

end → int
Byte offset one past the last character.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Byte offset of the first character.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override