VariableReference class final

A reference to an externally-supplied argument: $name.

Inheritance

Constructors

VariableReference(Identifier id, {Span? span})
References the variable named by id.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id Identifier
The variable name without the leading $.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span Span?
Source range this node covers; null when spans were off.
final

Methods

clone() VariableReference
Deep clone of this node.
override
equals(FluentNode other, {bool ignoreSpans = true}) bool
Structural equality.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited