UnterminatedStringError class final
E0020 — a string literal ran to end of line unterminated.
- Inheritance
-
- Object
- FluentParseError
- UnterminatedStringError
Constructors
- UnterminatedStringError(int offset)
-
Creates the error at
offset.const
Properties
- code → String
-
Stable identifier (e.g.
E0003).final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of what went wrong.
no setteroverride
- offset → int
-
Byte offset within the source where parsing failed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited