FluentNode class abstract
Base type for every Fluent Syntax 1.0 AST node.
- Implementers
- Annotations
-
- @immutable
Constructors
- FluentNode()
-
Base constructor for the sealed node family.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clone(
) → FluentNode - Deep clone of this node.
-
equals(
FluentNode other, {bool ignoreSpans = true}) → bool - Structural equality.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited