InlineExpression class sealed
An expression that can sit alone in a pattern or as a selector input.
Distinguishes from SelectExpression, which must be the only element
of its placeable's pattern. InlineExpression is also the type that
can be NESTED inside another placeable — { {"x"} } — because
Placeable implements this interface.
- Inheritance
-
- Object
- FluentNode
- SyntaxNode
- Expression
- InlineExpression
- Implementers
Properties
Methods
-
clone(
) → InlineExpression -
Deep clone of this node.
override
-
equals(
FluentNode other, {bool ignoreSpans = true}) → bool -
Structural equality.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited