Pattern class final
A pattern: the value of a Message, Term, or Attribute.
A pattern is a list of elements — runs of literal text alternated with
{ ... } placeables (expressions to substitute at format time).
- Inheritance
-
- Object
- FluentNode
- SyntaxNode
- Pattern
Constructors
-
Pattern(List<
PatternElement> elements, {Span? span}) -
Wraps the pattern's
elements.const
Properties
-
elements
→ List<
PatternElement> -
Text runs and placeables, in source order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → Span?
-
Source range this node covers; null when spans were off.
final
Methods
-
clone(
) → Pattern -
Deep clone of this node.
override
-
equals(
FluentNode other, {bool ignoreSpans = true}) → bool -
Structural equality.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited